==> igniteui-react-charts-16.16.3.tgz: package/esm2015/lib/PriceChannelOverlay_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialOverlay } from "./FinancialOverlay";
import { DependencyProperty } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { Number_$type, typeCast, runOn, markType, markDep, Point_$type, fromEnum } from "igniteui-react-core";
import { CategoryFrame } from "./CategoryFrame";
import { Series } from "./Series";
import { MathUtil } from "igniteui-react-core";
import { FinancialSeriesView } from "./FinancialSeriesView";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { Polyline } from "igniteui-react-core";
import { Polygon } from "igniteui-react-core";
import { RangeValueList } from "./RangeValueList";
import { PropertyMetadata } from "igniteui-react-core";
import { truncate, isNaN_, isInfinity } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
/**
 * @hidden
 */
export let PriceChannelOverlay = /*@__PURE__*/ (() => {
    class PriceChannelOverlay extends FinancialOverlay {
        constructor() {
            super();
            this.tt = new List$1(Number_$type, 0);
            this.ts = new List$1(Number_$type, 0);
            this.ab = PriceChannelOverlay.$;
            this.qg = new CategoryFrame(3);
            this.qi = new CategoryFrame(3);
            this.qe = new CategoryFrame(3);
        }
        l4(a, b, c, d) {
            switch (b) {
                case "HighColumn":
                case "LowColumn":
                    this.tm = false;
                    break;
            }
            super.l4(a, b, c, d);
            switch (b) {
                case PriceChannelOverlay.$$p[0]:
                    this.tm = false;
                    this.mi(false);
                    break;
            }
        }
        e9(a, b, c) {
            let d = super.e9(a, b, c);
            if (this.q6 == null || this.q7 == null) {
                d = false;
            }
            return d;
        }
        tn() {
            this.tt.clear();
            this.ts.clear();
            let a = truncate(MathUtil.c(this.tu, 0, this.ck.count));
            let b = Math.min(this.q6.count, this.q7.count);
            let c = this.rw(this.q6);
            let d = this.rw(this.q7);
            for (let e = 0; e < b; e++) {
                let f = Math.min(a, e);
                let g = -1.7976931348623157E+308;
                let h = 1.7976931348623157E+308;
                for (let i = 0; i < f; i++) {
                    if (!isNaN_(c.item(e - i))) {
                        g = Math.max(g, c.item(e - i));
                    }
                    if (!isNaN_(d.item(e - i))) {
                        h = Math.min(h, d.item(e - i));
                    }
                }
                if (e == 0) {
                    h = d.item(0);
                    g = c.item(0);
                }
                this.tt.add(g);
                this.ts.add(h);
            }
            return true;
        }
        s3(a, b) {
            super.s3(a, b);
            let c = b.bv;
            let d = b.bu;
            let e = this.getEffectiveViewport1(b);
            let f = new ScalerParams(0, c, d, this.qc.cg, e);
            let g = new ScalerParams(0, c, d, this.qy.cg, e);
            g.b = this.gc();
            let h = this.qc;
            let i = this.qy;
            a.f.clear();
            a.m.clear();
            a.p.clear();
            let j = 0;
            let k = typeCast(ISortingAxis_$type, this.qc);
            if (k != null && k.i$b.count != this.ck.count) {
                return;
            }
            j = this.r3(c, d, e);
            if (!this.tm) {
                this.tm = this.tn();
            }
            g.b = this.gc();
            let l = this.qc.el(2, f) - this.qc.el(1, f);
            for (let m = b.bx.c; m <= b.bx.d; ++m) {
                let n;
                if (k == null) {
                    n = b.bx.getBucket(m);
                }
                else {
                    let o = k.i$b._inner[m];
                    let p = k.i$d(o);
                    let q = this.tt._inner[m];
                    let r = this.ts._inner[m];
                    let s = q;
                    let t = r;
                    let u = p;
                    while (m < b.bx.d) {
                        o = k.i$b._inner[m + 1];
                        u = k.i$d(o);
                        if (u - p > l) {
                            break;
                        }
                        m++;
                        s = Math.max(q, this.tt._inner[m]);
                        t = Math.min(r, this.ts._inner[m]);
                    }
                    if (!isInfinity(t) && !isInfinity(s)) {
                        let v = NaN;
                        if (!isNaN_(p)) {
                            v = this.qc.ei(p, f);
                        }
                        n = [v, t, s];
                    }
                    else {
                        n = [NaN, NaN, NaN];
                    }
                }
                let w = Math.max(1, l);
                if (!isNaN_(n[0]) && m * w >= this.to) {
                    if (this.qc != null && typeCast(ISortingAxis_$type, this.qc) !== null) {
                        n[0] = n[0] + j;
                    }
                    else {
                        n[0] = h.ei(n[0], f) + j;
                    }
                    n[1] = i.ei(n[1], g);
                    n[2] = i.ei(n[2], g);
                    a.f.add(n);
                }
            }
        }
        kx(a, b) {
            super.kx(a, b);
            let c = b;
            if (c != null) {
                c.b4();
            }
        }
        s5(a, b) {
            super.s5(a, b);
            let c = typeCast(PriceChannelOverlayView.$, b);
            if (c == null) {
                return;
            }
            let d = this.getEffectiveViewport1(b);
            if (b.b0(a)) {
                c.b4();
                let e = a.f.count;
                let f = (g) => a.f._inner[g][0];
                let g = (h) => a.f._inner[e - 1 - h][0];
                let h = (i) => a.f._inner[i][1];
                let i = (j) => a.f._inner[e - 1 - j][2];
                c.b5(e, f, g, h, i);
                b.b2(a);
            }
            this.ql.a0(this, this.rk(), runOn(this, this.p4), this.r9(b), this.sb(b));
            let j = false;
            let k = this.ql.b;
            let l = a.f;
            let m = this.ck.count;
            if (k != null) {
                j = true;
            }
            if (j) {
                let n = new ScalerParams(0, b.bv, b.bu, this.qc.cg, d);
                this.s2(l, -1, m, this.qc, n, b.q);
            }
            let o = c.cb;
            let p = c.cc;
            let q = c.b7;
            this.ql.ad(o, true, false, true, true);
            this.ql.ad(p, true, false, true, true);
            this.ql.ad(q, false, true, false, false);
            q._opacity = this.ql.j * this.fq;
        }
        bx() {
            return new PriceChannelOverlayView(this);
        }
        lz(a) {
            super.lz(a);
            this.tr = typeCast(PriceChannelOverlayView.$, a);
        }
        gj(a, b, c) {
            if (this.cd == null) {
                return NaN;
            }
            let d = this.getEffectiveViewport1(this.b0);
            let e = new ScalerParams(0, this.cd.sf, this.b0.bu, this.qc.cg, d);
            let f = this.r3(this.cd.sf, this.b0.bu, d);
            return this.gl(new RangeValueList(this.tt, this.ts), a, this.qc, e, f, runOn(this, this.r2), b, c);
        }
        hh(a, b) {
            if (this.tt == null || this.ts == null) {
                return super.hh(a, b);
            }
            return this.hi(a, b, this.qc, runOn(this, this.r2), new RangeValueList(this.tt, this.ts));
        }
        hj(a, b) {
            if (this.tt == null || this.ts == null) {
                return super.hj(a, b);
            }
            return this.hk(a, b, this.qc, runOn(this, this.r2), new RangeValueList(this.tt, this.ts));
        }
        gc() {
            return Series.ge(this.ts, null);
        }
    }
    PriceChannelOverlay.$t = /*@__PURE__*/ markType(PriceChannelOverlay, 'PriceChannelOverlay', FinancialOverlay.$);
    PriceChannelOverlay.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, PriceChannelOverlay, 'raisePropertyChanged', ['Period:tu:tw', [1, 14]]);
    return PriceChannelOverlay;
})();
/**
 * @hidden
 */
export let PriceChannelBucketCalculator = /*@__PURE__*/ (() => {
    class PriceChannelBucketCalculator extends FinancialBucketCalculator {
        constructor(a) {
            super(a);
            this.f = null;
            this.f = a;
        }
        getBucket(a) {
            let b = a * this.b;
            let c = Math.min(b + this.b - 1, this.a.bz.ck.count - 1);
            if (b <= c) {
                let d = -1.7976931348623157E+308;
                let e = 1.7976931348623157E+308;
                let f = 0;
                for (let g = b; g <= c; ++g) {
                    if (!isNaN_(this.f.b3.tt._inner[g]) && !isNaN_(this.f.b3.ts._inner[g])) {
                        d = Math.max(d, this.f.b3.tt._inner[g]);
                        e = Math.min(e, this.f.b3.ts._inner[g]);
                        ++f;
                    }
                }
                if (f > 0 && e != 1.7976931348623157E+308 && d != -1.7976931348623157E+308) {
                    return [0.5 * (b + c), e, d];
                }
            }
            return [NaN, NaN, NaN];
        }
    }
    PriceChannelBucketCalculator.$t = /*@__PURE__*/ markType(PriceChannelBucketCalculator, 'PriceChannelBucketCalculator', FinancialBucketCalculator.$);
    return PriceChannelBucketCalculator;
})();
/**
 * @hidden
 */
export let PriceChannelOverlayView = /*@__PURE__*/ (() => {
    class PriceChannelOverlayView extends FinancialSeriesView {
        constructor(a) {
            super(a);
            this.b8 = new Polygon();
            this.cd = new Polyline();
            this.ce = new Polyline();
            this.b3 = null;
            this.b6 = new Polygon();
            this.b9 = new Polyline();
            this.ca = new Polyline();
            this.b3 = a;
        }
        get b7() {
            return this.b8;
        }
        get cb() {
            return this.cd;
        }
        get cc() {
            return this.ce;
        }
        as() {
            super.as();
            if (!this.q) {
            }
        }
        by() {
            return new PriceChannelBucketCalculator(this);
        }
        b4() {
            this.b8.ak.clear();
            this.cd.ak.clear();
            this.ce.ak.clear();
            this.aq();
        }
        b5(a, b, c, d, e) {
            for (let f of fromEnum(Flattener.d(a, b, d, this.e.ft))) {
                this.b8.ak.add({ $type: Point_$type, x: b(f), y: d(f) });
                this.cd.ak.add({ $type: Point_$type, x: b(f), y: d(f) });
            }
            for (let g of fromEnum(Flattener.d(a, c, e, this.e.ft))) {
                this.b8.ak.add({ $type: Point_$type, x: c(g), y: e(g) });
                this.ce.ak.add({ $type: Point_$type, x: c(g), y: e(g) });
            }
            this.aq();
        }
        bc() {
            super.bc();
            this.b6.ak = this.b8.ak;
            this.b9.ak = this.cd.ak;
            this.ca.ak = this.ce.ak;
            let a = this.bo();
            this.b6._fill = a;
            this.b6._opacity = 1;
            this.b9._stroke = a;
            this.b9.ac = this.e.fu + 3;
            this.ca._stroke = a;
            this.ca.ac = this.e.fu + 3;
        }
        a6(a, b) {
            super.a6(a, b);
            if (a.d) {
                if (b) {
                    a.t(this.b6);
                    a.u(this.b9);
                    a.u(this.ca);
                }
                else {
                    a.t(this.b8);
                    a.u(this.cd);
                    a.u(this.ce);
                }
            }
        }
        al(a) {
            super.al(a);
            this.e.a8.exportPolygonData(a, this.b8, "fill", ["Fill"]);
            this.e.a8.exportPolylineData(a, this.cd, "bottom", ["Lower", "Main"]);
            this.e.a8.exportPolylineData(a, this.ce, "top", ["Upper"]);
        }
    }
    PriceChannelOverlayView.$t = /*@__PURE__*/ markType(PriceChannelOverlayView, 'PriceChannelOverlayView', FinancialSeriesView.$);
    return PriceChannelOverlayView;
})();

==> igniteui-react-charts-18.1.0.tgz: package/esm2015/lib/PriceChannelOverlay_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialOverlay } from "./FinancialOverlay";
import { DependencyProperty } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { Number_$type, typeCast, runOn, markType, markDep, Point_$type, fromEnum } from "igniteui-react-core";
import { CategoryFrame } from "./CategoryFrame";
import { Series } from "./Series";
import { MathUtil } from "igniteui-react-core";
import { FinancialSeriesView } from "./FinancialSeriesView";
import { ScalerParams } from "./ScalerParams";
import { ISortingAxis_$type } from "./ISortingAxis";
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { Polyline } from "igniteui-react-core";
import { Polygon } from "igniteui-react-core";
import { RangeValueList } from "./RangeValueList";
import { PropertyMetadata } from "igniteui-react-core";
import { truncate, isNaN_, isInfinity } from "igniteui-react-core";
import { Flattener } from "igniteui-react-core";
/**
 * @hidden
 */
export let PriceChannelOverlay = /*@__PURE__*/ (() => {
    class PriceChannelOverlay extends FinancialOverlay {
        constructor() {
            super();
            this.tx = new List$1(Number_$type, 0);
            this.tw = new List$1(Number_$type, 0);
            this.ab = PriceChannelOverlay.$;
            this.qk = new CategoryFrame(3);
            this.qm = new CategoryFrame(3);
            this.qi = new CategoryFrame(3);
        }
        l7(a, b, c, d) {
            switch (b) {
                case "HighColumn":
                case "LowColumn":
                    this.tq = false;
                    break;
            }
            super.l7(a, b, c, d);
            switch (b) {
                case PriceChannelOverlay.$$p[0]:
                    this.tq = false;
                    this.ml(false);
                    break;
            }
        }
        fb(a, b, c) {
            let d = super.fb(a, b, c);
            if (this.ra == null || this.rb == null) {
                d = false;
            }
            return d;
        }
        tr() {
            this.tx.clear();
            this.tw.clear();
            let a = truncate(MathUtil.d(this.ty, 0, this.ck.count));
            let b = Math.min(this.ra.count, this.rb.count);
            let c = this.r0(this.ra);
            let d = this.r0(this.rb);
            for (let e = 0; e < b; e++) {
                let f = Math.min(a, e);
                let g = -1.7976931348623157E+308;
                let h = 1.7976931348623157E+308;
                for (let i = 0; i < f; i++) {
                    if (!isNaN_(c.item(e - i))) {
                        g = Math.max(g, c.item(e - i));
                    }
                    if (!isNaN_(d.item(e - i))) {
                        h = Math.min(h, d.item(e - i));
                    }
                }
                if (e == 0) {
                    h = d.item(0);
                    g = c.item(0);
                }
                this.tx.add(g);
                this.tw.add(h);
            }
            return true;
        }
        s7(a, b) {
            super.s7(a, b);
            let c = b.bv;
            let d = b.bu;
            let e = this.getEffectiveViewport1(b);
            let f = new ScalerParams(0, c, d, this.qg.cg, e);
            let g = new ScalerParams(0, c, d, this.q2.cg, e);
            g.b = this.ge();
            let h = this.qg;
            let i = this.q2;
            a.f.clear();
            a.m.clear();
            a.p.clear();
            let j = 0;
            let k = typeCast(ISortingAxis_$type, this.qg);
            if (k != null && k.i$b.count != this.ck.count) {
                return;
            }
            j = this.r7(c, d, e);
            if (!this.tq) {
                this.tq = this.tr();
            }
            g.b = this.ge();
            let l = this.qg.el(2, f) - this.qg.el(1, f);
            for (let m = b.bx.c; m <= b.bx.d; ++m) {
                let n;
                if (k == null) {
                    n = b.bx.getBucket(m);
                }
                else {
                    let o = k.i$b._inner[m];
                    let p = k.i$d(o);
                    let q = this.tx._inner[m];
                    let r = this.tw._inner[m];
                    let s = q;
                    let t = r;
                    let u = p;
                    while (m < b.bx.d) {
                        o = k.i$b._inner[m + 1];
                        u = k.i$d(o);
                        if (u - p > l) {
                            break;
                        }
                        m++;
                        s = Math.max(q, this.tx._inner[m]);
                        t = Math.min(r, this.tw._inner[m]);
                    }
                    if (!isInfinity(t) && !isInfinity(s)) {
                        let v = NaN;
                        if (!isNaN_(p)) {
                            v = this.qg.ei(p, f);
                        }
                        n = [v, t, s];
                    }
                    else {
                        n = [NaN, NaN, NaN];
                    }
                }
                let w = Math.max(1, l);
                if (!isNaN_(n[0]) && m * w >= this.ts) {
                    if (this.qg != null && typeCast(ISortingAxis_$type, this.qg) !== null) {
                        n[0] = n[0] + j;
                    }
                    else {
                        n[0] = h.ei(n[0], f) + j;
                    }
                    n[1] = i.ei(n[1], g);
                    n[2] = i.ei(n[2], g);
                    a.f.add(n);
                }
            }
        }
        k0(a, b) {
            super.k0(a, b);
            let c = b;
            if (c != null) {
                c.b4();
            }
        }
        s9(a, b) {
            super.s9(a, b);
            let c = typeCast(PriceChannelOverlayView.$, b);
            if (c == null) {
                return;
            }
            let d = this.getEffectiveViewport1(b);
            if (b.b0(a)) {
                c.b4();
                let e = a.f.count;
                let f = (g) => a.f._inner[g][0];
                let g = (h) => a.f._inner[e - 1 - h][0];
                let h = (i) => a.f._inner[i][1];
                let i = (j) => a.f._inner[e - 1 - j][2];
                c.b5(e, f, g, h, i);
                b.b2(a);
            }
            this.qp.a0(this, this.ro(), runOn(this, this.p8), this.sd(b), this.sf(b));
            let j = false;
            let k = this.qp.b;
            let l = a.f;
            let m = this.ck.count;
            if (k != null) {
                j = true;
            }
            if (j) {
                let n = new ScalerParams(0, b.bv, b.bu, this.qg.cg, d);
                this.s6(l, -1, m, this.qg, n, b.q);
            }
            let o = c.cb;
            let p = c.cc;
            let q = c.b7;
            this.qp.ad(o, true, false, true, true);
            this.qp.ad(p, true, false, true, true);
            this.qp.ad(q, false, true, false, false);
            q._opacity = this.qp.j * this.fs;
        }
        bx() {
            return new PriceChannelOverlayView(this);
        }
        l2(a) {
            super.l2(a);
            this.tv = typeCast(PriceChannelOverlayView.$, a);
        }
        gl(a, b, c) {
            if (this.cd == null) {
                return NaN;
            }
            let d = this.getEffectiveViewport1(this.b0);
            let e = new ScalerParams(0, this.cd.s9, this.b0.bu, this.qg.cg, d);
            let f = this.r7(this.cd.s9, this.b0.bu, d);
            return this.gn(new RangeValueList(this.tx, this.tw), a, this.qg, e, f, runOn(this, this.r6), b, c);
        }
        hj(a, b) {
            if (this.tx == null || this.tw == null) {
                return super.hj(a, b);
            }
            return this.hk(a, b, this.qg, runOn(this, this.r6), new RangeValueList(this.tx, this.tw));
        }
        hl(a, b) {
            if (this.tx == null || this.tw == null) {
                return super.hl(a, b);
            }
            return this.hm(a, b, this.qg, runOn(this, this.r6), new RangeValueList(this.tx, this.tw));
        }
        ge() {
            return Series.gg(this.tw, null);
        }
    }
    PriceChannelOverlay.$t = /*@__PURE__*/ markType(PriceChannelOverlay, 'PriceChannelOverlay', FinancialOverlay.$);
    PriceChannelOverlay.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, PriceChannelOverlay, 'raisePropertyChanged', ['Period:ty:t0', [1, 14]]);
    return PriceChannelOverlay;
})();
/**
 * @hidden
 */
export let PriceChannelBucketCalculator = /*@__PURE__*/ (() => {
    class PriceChannelBucketCalculator extends FinancialBucketCalculator {
        constructor(a) {
            super(a);
            this.f = null;
            this.f = a;
        }
        getBucket(a) {
            let b = a * this.b;
            let c = Math.min(b + this.b - 1, this.a.bz.ck.count - 1);
            if (b <= c) {
                let d = -1.7976931348623157E+308;
                let e = 1.7976931348623157E+308;
                let f = 0;
                for (let g = b; g <= c; ++g) {
                    if (!isNaN_(this.f.b3.tx._inner[g]) && !isNaN_(this.f.b3.tw._inner[g])) {
                        d = Math.max(d, this.f.b3.tx._inner[g]);
                        e = Math.min(e, this.f.b3.tw._inner[g]);
                        ++f;
                    }
                }
                if (f > 0 && e != 1.7976931348623157E+308 && d != -1.7976931348623157E+308) {
                    return [0.5 * (b + c), e, d];
                }
            }
            return [NaN, NaN, NaN];
        }
    }
    PriceChannelBucketCalculator.$t = /*@__PURE__*/ markType(PriceChannelBucketCalculator, 'PriceChannelBucketCalculator', FinancialBucketCalculator.$);
    return PriceChannelBucketCalculator;
})();
/**
 * @hidden
 */
export let PriceChannelOverlayView = /*@__PURE__*/ (() => {
    class PriceChannelOverlayView extends FinancialSeriesView {
        constructor(a) {
            super(a);
            this.b8 = new Polygon();
            this.cd = new Polyline();
            this.ce = new Polyline();
            this.b3 = null;
            this.b6 = new Polygon();
            this.b9 = new Polyline();
            this.ca = new Polyline();
            this.b3 = a;
        }
        get b7() {
            return this.b8;
        }
        get cb() {
            return this.cd;
        }
        get cc() {
            return this.ce;
        }
        as() {
            super.as();
            if (!this.q) {
            }
        }
        by() {
            return new PriceChannelBucketCalculator(this);
        }
        b4() {
            this.b8.ak.clear();
            this.cd.ak.clear();
            this.ce.ak.clear();
            this.aq();
        }
        b5(a, b, c, d, e) {
            for (let f of fromEnum(Flattener.d(a, b, d, this.e.fv))) {
                this.b8.ak.add({ $type: Point_$type, x: b(f), y: d(f) });
                this.cd.ak.add({ $type: Point_$type, x: b(f), y: d(f) });
            }
            for (let g of fromEnum(Flattener.d(a, c, e, this.e.fv))) {
                this.b8.ak.add({ $type: Point_$type, x: c(g), y: e(g) });
                this.ce.ak.add({ $type: Point_$type, x: c(g), y: e(g) });
            }
            this.aq();
        }
        bc() {
            super.bc();
            this.b6.ak = this.b8.ak;
            this.b9.ak = this.cd.ak;
            this.ca.ak = this.ce.ak;
            let a = this.bo();
            this.b6._fill = a;
            this.b6._opacity = 1;
            this.b9._stroke = a;
            this.b9.ac = this.e.fw + 3;
            this.ca._stroke = a;
            this.ca.ac = this.e.fw + 3;
        }
        a6(a, b) {
            super.a6(a, b);
            if (a.d) {
                if (b) {
                    a.t(this.b6);
                    a.u(this.b9);
                    a.u(this.ca);
                }
                else {
                    a.t(this.b8);
                    a.u(this.cd);
                    a.u(this.ce);
                }
            }
        }
        al(a) {
            super.al(a);
            this.e.a8.exportPolygonData(a, this.b8, "fill", ["Fill"]);
            this.e.a8.exportPolylineData(a, this.cd, "bottom", ["Lower", "Main"]);
            this.e.a8.exportPolylineData(a, this.ce, "top", ["Upper"]);
        }
    }
    PriceChannelOverlayView.$t = /*@__PURE__*/ markType(PriceChannelOverlayView, 'PriceChannelOverlayView', FinancialSeriesView.$);
    return PriceChannelOverlayView;
})();
